==> cloudfront-1.173.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnOriginAccessControlProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `CfnOriginAccessControl`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudfront.*;
 * CfnOriginAccessControlProps cfnOriginAccessControlProps = CfnOriginAccessControlProps.builder()
 *         .originAccessControlConfig(OriginAccessControlConfigProperty.builder()
 *                 .name("name")
 *                 .originAccessControlOriginType("originAccessControlOriginType")
 *                 .signingBehavior("signingBehavior")
 *                 .signingProtocol("signingProtocol")
 *                 // the properties below are optional
 *                 .description("description")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:32.841Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnOriginAccessControlProps")
@software.amazon.jsii.Jsii.Proxy(CfnOriginAccessControlProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnOriginAccessControlProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudFront::OriginAccessControl.OriginAccessControlConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getOriginAccessControlConfig();

    /**
     * @return a {@link Builder} of {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnOriginAccessControlProps> {
        java.lang.Object originAccessControlConfig;

        /**
         * Sets the value of {@link CfnOriginAccessControlProps#getOriginAccessControlConfig}
         * @param originAccessControlConfig `AWS::CloudFront::OriginAccessControl.OriginAccessControlConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlConfig(software.amazon.awscdk.core.IResolvable originAccessControlConfig) {
            this.originAccessControlConfig = originAccessControlConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginAccessControlProps#getOriginAccessControlConfig}
         * @param originAccessControlConfig `AWS::CloudFront::OriginAccessControl.OriginAccessControlConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlConfig(software.amazon.awscdk.services.cloudfront.CfnOriginAccessControl.OriginAccessControlConfigProperty originAccessControlConfig) {
            this.originAccessControlConfig = originAccessControlConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnOriginAccessControlProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnOriginAccessControlProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnOriginAccessControlProps {
        private final java.lang.Object originAccessControlConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.originAccessControlConfig = software.amazon.jsii.Kernel.get(this, "originAccessControlConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.originAccessControlConfig = java.util.Objects.requireNonNull(builder.originAccessControlConfig, "originAccessControlConfig is required");
        }

        @Override
        public final java.lang.Object getOriginAccessControlConfig() {
            return this.originAccessControlConfig;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("originAccessControlConfig", om.valueToTree(this.getOriginAccessControlConfig()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnOriginAccessControlProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnOriginAccessControlProps.Jsii$Proxy that = (CfnOriginAccessControlProps.Jsii$Proxy) o;

            return this.originAccessControlConfig.equals(that.originAccessControlConfig);
        }

        @Override
        public final int hashCode() {
            int result = this.originAccessControlConfig.hashCode();
            return result;
        }
    }
}

==> cloudfront-1.182.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnOriginAccessControlProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `CfnOriginAccessControl`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudfront.*;
 * CfnOriginAccessControlProps cfnOriginAccessControlProps = CfnOriginAccessControlProps.builder()
 *         .originAccessControlConfig(OriginAccessControlConfigProperty.builder()
 *                 .name("name")
 *                 .originAccessControlOriginType("originAccessControlOriginType")
 *                 .signingBehavior("signingBehavior")
 *                 .signingProtocol("signingProtocol")
 *                 // the properties below are optional
 *                 .description("description")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:44.242Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnOriginAccessControlProps")
@software.amazon.jsii.Jsii.Proxy(CfnOriginAccessControlProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnOriginAccessControlProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The origin access control.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getOriginAccessControlConfig();

    /**
     * @return a {@link Builder} of {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnOriginAccessControlProps> {
        java.lang.Object originAccessControlConfig;

        /**
         * Sets the value of {@link CfnOriginAccessControlProps#getOriginAccessControlConfig}
         * @param originAccessControlConfig The origin access control. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlConfig(software.amazon.awscdk.core.IResolvable originAccessControlConfig) {
            this.originAccessControlConfig = originAccessControlConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginAccessControlProps#getOriginAccessControlConfig}
         * @param originAccessControlConfig The origin access control. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlConfig(software.amazon.awscdk.services.cloudfront.CfnOriginAccessControl.OriginAccessControlConfigProperty originAccessControlConfig) {
            this.originAccessControlConfig = originAccessControlConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnOriginAccessControlProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnOriginAccessControlProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnOriginAccessControlProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnOriginAccessControlProps {
        private final java.lang.Object originAccessControlConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.originAccessControlConfig = software.amazon.jsii.Kernel.get(this, "originAccessControlConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.originAccessControlConfig = java.util.Objects.requireNonNull(builder.originAccessControlConfig, "originAccessControlConfig is required");
        }

        @Override
        public final java.lang.Object getOriginAccessControlConfig() {
            return this.originAccessControlConfig;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("originAccessControlConfig", om.valueToTree(this.getOriginAccessControlConfig()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnOriginAccessControlProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnOriginAccessControlProps.Jsii$Proxy that = (CfnOriginAccessControlProps.Jsii$Proxy) o;

            return this.originAccessControlConfig.equals(that.originAccessControlConfig);
        }

        @Override
        public final int hashCode() {
            int result = this.originAccessControlConfig.hashCode();
            return result;
        }
    }
}
